bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 26. Aventiure
___________________________________________________ #### <Wie Danchwart Gelffraten slvch>
| ### o si nv waren alle komen vf den sant ### der kvnich begvnde vragen wer sol vns durch din lant ### die reken wege wisen daz wir niht irre varn ### do sprach der starke Volker daz sol ich eine bewarn
###### 1527 | ### Nv enthalt iv sprach sagne ritter vn– kneht ### man sol vriunden volgen ia dunchet ez mich reht ### vil vngefuoge mere die tuon ich iv bekant ### wiren komen nimmer mere wider in der Burgonden lant
###### 1528 | ### Daz sagten mir zwai merwip hivte morgen fruo ### daz wir niht komen widere nv rat ich waz man tvo ### daz ir iuch wafent helde ir svlt iuch wol bewarn ### wir haben hie starke viende daz wir gewerlichen varn
###### 1529 | ### Ich wande an lvge vinden div wisen merwip ### si ialhen daz gesvnder vnser deheines lip ### nimmer ce lande keme niwan der kappelan ### darvmbe ich in so gerne wolte hivte ertrenket han
###### 1530 | ### Do flvgen dise mere von schare baz ze schare ### des wurden snelle helde missevare ### do si begvnden sorgen uf den herten tot ### an dirre hovereise des gie in werlichen not
###### 1531 | ### Da ce Moringen si waren vber komen ### da dem Elsen vergen der lip was genomen ### do sprach aber Hagne sit daz ich vinde han ### verdienet vf der straze wir werden scherliche bestan
###### 1532 | ### Ich sluoc den selben vergen hivte morgen fruo ### si wizen wol div mere nv grifet balde zuo ### do Gelfrat vn– Else hivte hie beste ### vnser ingesinde daz ez in schedilich erge
###### 1533 | ### Iich erkenne si so kuene ez wirdet niht verlan [62b] ### div ros svlt ir lazen dester samfter gan ### daz des iemen wene wir fliehen vf den wegen ### des rates wil ich volgen so sprach Giselher der degen
###### 1534 | ### Wer sol daz gesinde wisen hin vber lant ### si sprachen daz tuo Volker dem ist ez hie wol bekant ### stige vn– straze der kuene spilman ### ê daz man vollen gerte man sach wol gewafent stan
###### 1535 | ### den snellen videlere den helm er vf gebant ### in herlicher varwe was sin wicgewant ### er bant ovch zeime schafte ein zeichen daz <was> rot ### sit chom er mit den kvnigen in ein vreisliche not
###### 1536 | ### Do was tot der vergen Gelpfrate chomen ### mit wisen meren do het ez ovch vernomen ### Else der vil starke ez was in beiden leit ### si sanden nach ir helden die waren vil schiere bereit
###### 1537 | ### In vil kvrzcen citen ich wil iv horen lan ### sach man zuo cin riten die schaden heten getan ### in starken vrlevgen vil vngefuege schar ### der komen Gelpfraten wol siben hvn–dert <ce> helfe dar
###### 1538 | ### Do si grimmen vienden begvnden riten nach ### ia leiten si ir herren den was ein teil ze gah ### nach den kuenen gesten si wolten anden ir zorn ### des wart der herten vrivnden sider mer verlorn
###### 1539 | ### Do het von Trony Hagne wol gefueget daz ### wie mohte siner mage ein helt gehueten baz ### er pflach der nachhûte mit den sinen man ### vn– Dancwart sin bruoder daz was vil willichlic getan
###### 1540 | ### In was des tages zerrvnnen desen heten si niht mer ### er vorht an sinen vrivnden leit vn– ser ### si riten vnder schilten durch der Beier lant ### darnach in churzer wile die helde wurden an gerant
###### 1541 | ### Beindenthalp der straze vn– hinden vaste nach ### si horten huove claffen dem livte was so gach ### do sprach der kuene Dancwart man wil hie bestan ### nv binden vf die helme daz ist ræhlich getan
###### 1542 | ### Si hilten ab ir verte als mvose sin ### si sahen in der vinster der liehten schilde schin ### done wolte Hagene niht langer si verdagen ### wer iach vns vf der straze daz mvoz im Gelpfart do sagen
###### 1543 | ### Do sprach der marchgraue uzer Beierlant ### wir suochen vnser viende vn– haben her nach gerant ### ich enweiz niht wer mir hivte minen vergen sluoch ### der was ein helt zen handen des ist mir leide genuoch
###### 1544 | ### Do sprac von Troni Hagne was der verge din ### der wolte vns niht fuoren des ist div schvlde min ### do sluoch ich den reken daz ist war des gie mir not ### ich hete von sinen handen nach den grimmigen tot
###### 1545 | ### Ich bot im ze miete golt vnd ovch gewant ### daz er vns uber fuorte helt in din lant ### daz zvrner so sere daz er mich do sluoch [63a] ### mit einer starken schalten des wart ich grimme genvoc
###### 1546 | ### Do chom ich zvo dern swerte vn– wert in sinem zorn ### mit einer starken wunden des wart der helt verlorn ### daz bringe ich iv ze suone swie iuch dvnket guot ### do gie ez an ein striten si waren herte emvot
###### 1547 | ### Ich wesse wol sprach Gelpfrat do hie fur gereit ### Gvnther vn– sin gesinde daz vns tete leit ### Hagne von Tronie nu sol er niht genesen ### fur des vergen hende der helt mvoz hie bvrge wesen
###### 1548 | ### Si neigeten vber schilte ze stichen nv div sper ### Gelpfrat vn– Hagne in was ze ein ander ger ### Else vn– Dancwart vil herlichen riten ### si versuochten wer si waren da wart vil grimme gestriten
###### 1549 | ### Wie mohten sich versuochen immer helde baz ### von einer starken tyost hinder daz ros gesazen ### Hagne der kuene von Gelpfrates hant ### im brast daz furbuege des wart im striten bekant
###### 1550 | ### Von ir ingesinde des crafth der schefte schal ### do erholte ovch sich dort Hagne da er was zetal ### komen von dem stiche nider vf daz gras ### ich wene er vnsampftes mvotes wider Gelpfraten was
###### 1551 | ### Wer in div ros behielte daz ist mir vnbekant ### si waren zuo der erden komen vf den sant ### Hagne vn– Gelpfrat ein ander liefens an ### des hvlfen ir gesellen daz in wart striten kvnt getan
###### 1552 | ### Swie biterlichen Hagne zvo Gelfrate spranc ### der edele marchgraue des schiltes hin im swanc ### ein vil michel stuche daz fuor drate dan ### des was vil nah erstorben des kvnich Gvntheres man
###### 1553 | ### Do begvnde er ruofen Dancwarten vil vaste an ### hilfa lieber bruoder ia hat mich bestan ### ein helt zuo sinen handen deren lat mich niht genesen ### do sprach der kuene Dancwart <des> sol ich scheider wesen
###### 1554 | ### Der helt do spranch dar naher vn– sluoc im einen slac ### mit eime scharphen wafen davon er tot gelac ### Else wolte do gerne reken do den man ### er vn– sin gesinde si schieden schedelichen dan
###### 1555 | ### Im was erslagen der bruoder selbe wart er wunt ### wol ahzech siner degne beliben da zestvnt ### mit dem grimmen tode der herre mvose dan ### fluhticlichen wenden von den Gvnthers man
###### 1556 | ### Do die von Beierlande wichen vz dem wege ### do horte man nach hellen die freislichen slege ### do iagten die von Tronie ir vienden nach ### di si niht enkelten wanden was allen ze gah
###### 1557 | ### Do sprach an ir fluhte Dancwart der degen ### wir svln wider wenden balde vf disen wegen ### vn– laze wir si riten si sint von bluote naz ### gahen wir zen vriunden ich rate werlichen daz
###### 1558 | ### Do si hin wider komen da der schade was geschehen [63b] ### do sprach von Troni Hagne helde ir svlt besehen ### wes vns hie gebreste oder wen wir han verlorn ### hie in disem strite durch den Gelfrates zorn
###### 1559 | ### Si heten verlorn viere die mvosen si verslagen ### die waren wol vergolten da wider was erslagen ### der von Beierlant hvndert oder baz ### des waren den von Tronie ir schilte truchen vn– <bluotes> naz
###### 1560 | ### Ein teil schein vz den wolken des liehten manen prehen ### do sprach aber Hagne niemen sol veriehen ### den minen lieben herren waz wir hie haben getan ### lat si vnz morgen ane sorge bestan
###### 1561 | ### Do si nv nach in komen di dort striten ê ### do tet dem ingesinde div muede harte we ### wie lange sul wir riten des vragte manic man ### do sprach der kuene Dancwart wir mvgen niht herbergen han
###### 1562 | ### Ir muozet alle riten vnz ez werde tac ### Volker der snelle der des gesindes pflac ### bat den marsalch vragen wa sul wir hinte sin ### da gerasten vnser moere vnd ovch die lieben herren min
###### 1563 | ### Do sprach der kuene Dancwart ich en kans iuch niht gesagen ### wir mvgen niht geruewen enz beginde tagen ### swa wir danne vinden da legen vns an ein gras ### do si div mere horten wie leit in svmeleichen was
###### 1564 | ### Si biliben vnuermeldet des herzen bluotes rot ### vnz daz disiv svnne ir liehtez schinen bot ### der morgen vber berge daz ez der kvnich gesach ### daz si gestriten heten der helt vil zorneclichen sprach
###### 1565 | ### Wie nv frivnt Hagne iv wene versmahet daz ### daz ich iv bi were da iv die ringe naz ### svs wurden von dem bluote wer hat daz getan ### er sprach daz tet Else der het vns nehten bestan
###### 1566 | ### Dvrch sinen vergen wir wurden an gerant ### do sluoc Gelfraten mines bruoder hant ### sid entran vns Else des twanch in michel not ### in hvndert vn– vns viere beliben da in strite tot
###### 1567 | ### Wir kvnnen niht bescheiden wa si sich leiten nider ### al die lantlûte gefrieschen sider ### daz ce hove fueren der edelen voten kint ### si wurden wol enphangen daz ze Pazzawe sit
###### 1568 | ### Der edelen kvnige oheim der bischof Pilgrim ### dem wart vil wol ze mvote do die neven sin ### mit alse vil reken komen in daz lant ### daz er in willech were daz wart in schier bekant
###### 1569 | ### Si wurden wol enphangen von vriunden vf den wegen ### daz ze Pazzowe man kvnder niht gephlegen ### si mvozen vber wazzer da si funden velt ### da wurden vf gespannen hutten vn– rich gecelt
###### 1570 | ### Si mvosen da beliben allen einen tac ### vn– ovch die naht mit vollen wie schone man ir pflac ### darnach si mvosen riten in Ruedigeres lant [64a] ### den wurden ovch div mere danach schiere bekant
###### 1571 | ### Do die wegemuoden rûwe genamen ### vn– si dem lande nv naher quamen ### do fundens vf der marche slafende einen man ### dem von Trony Hagne ein starchez wafen an gewan
###### 1572 | ### Ia was geheizen Ekewart der selbe riter gvot ### er gewan darvmbe vil trurigen mvot ### daz er verlos daz wafen von der helde vart ### die Ruediders marke fvnden si vbele bewart
###### 1573 | ### Owe mir dirre schande sprach do Ekewart ### ia riwet mich vil sere der Burgonden vart ### sit ich verlos Sifriden sid was min vrevde ergan ### ovwe herre Rovdiger wie han ich wider dich getan
###### 1574 | ### Wol horte Hagne des edelen reken not ### er gab im wider sin wafen vn– sehs bovge rot ### die habe dir helt ce minnen daz dv min frivnt sist ### dv bist ein degen kvener swie eine dv hie list
###### 1575 | ### Got lone iv iwer bovge sprach do Ekewart ### doch riwet mich vil sere cen Hvnen iwer vart ### ir slvoget Sifriden man ist iv hie gehaz ### daz ir ivch wol huotet in triwen rate ivch daz
###### 1576 | ### Nv mueze vns got behveten sprach do Hagne ### ia hant niht mere sorge dise degene ### wan vm die herberge die kvnige vnd ir man ### wa wir in disem lande noch heint nah selde han
###### 1577 | ### Div ros sint vns verdorben vf den verren wegen ### vn– spise zerrvnnen sprach Hagene der degen ### wir vindenz nider veile vns wer wirtes not ### der vns heint gebe durch sin tvgent daz brot
###### 1578 | ### Do sprach aber Ekewart ich zeig iv einen wirt ### daz ir ze husen selten baz komen birt ### in deheime lande als iv hie mac geschehen ### ob ir snelle degne welt Ruedigeren sehen
###### 1579 | ### Der sizet bi der straze vnd ist der beste wirt ### der ie kom ze straze sin herze tvgende birt ### alsam der sueze meie daz gras mit bluomen tvot ### so er sol helden dienen so ist er vro gemvot
###### 1580 | ### Do sprach der kvnich Gvnther welt ir min bote sin ### ob vns welle behalten durch den willen min ### min lieber vriunt Ruediger min mage vn– vns man ### daz wil ich immer dienen so ich aller beste kan
###### 1581 | ### Der bote bin ich gerne sprach do Echewart ### mit vil guotem willen huob er sich an die vart ### vn– seite Ruedigere als er hete vernomen ### im was in langen ziten niht so lieber mære komen
###### 1582 | ### Man sach ce Bechlaren ilen einen degen ### selbe erkand in Ruediger er sprach vf disen wegen ### dort her gahet Ekewart ein Kriemhilde man ### er wande daz im die viende im heten leide getan
###### 1583 | ### Do gie er fur die porte da er den poten vant [64b] ### daz swert er abe gurte vn– leitez von der hant ### div mere die er brahte wurden niht verdaget ### den wirt vn– sine vrivnde ez wart in schiere gesaget
###### 1584 | ### Er sprach cem marchgraven mich hat zv iv gesant ### Gvnther min herre von Burgonden lant ### vn– Giselher sin bruoder vn– ovch Gernot ### der reken ieslicher iv sinen dienst her enbot
###### 1585 | ### Daz selbe hat ovch Hagene dar zuo Volker ### mit triwen flizeclichen noch sag ich iv mer ### daz iv des kvniges marsalch bi mir daz enbot ### daz den guoten knehten were iwere herberge not
###### 1586 | ### Mit lachendem mvote antwurte Ruediger ### nv wol mich dirre mere daz die kvnige her ### geruochent miner dienste derin wirt niht verseit ### koment si mir ze huse des bin ich vrolich gemeit
###### 1587 | ### Dancwart der marsalch hiez iv wizzen lan ### wen ir ze hûse mit in soldet han ### sehzech sneller reken vnd tvsent riter guot ### vnd nivn tvsent knehte do wart er vrolich gemvot
###### 1588 | ### Nv wol mich dirre geste sprach do Ruediger ### daz mir koment ze hvse dise reken her ### den ich noch vil selten iht gedienet han ### nv ritet in enkegene beide mage vn– man
###### 1589 | ### Do ilten zvo den rossen ritter vn– kneht ### swaz in gebot ir herre daz dvhtes alle reht ### do liezens in der dienste zogen deste baz ### ez wesse niht vrov Goetelint div in ir kemenaten saz

<<< Übersicht <<< vorige Seite nächste Seite >>>